import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

//importing Iris data from gist
const csvUrl = [
  'https://gist.githubusercontent.com/',
  'curran/', // User
  'a08a1080b88344b0c8a7/', // Id of the Gist
  'raw/0e7a9b0a5d22642a06d3d5b9bcbad9890c8ee534/', // commit
  'iris.csv', // File name
].join('');
//reads rows in a sheet
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};


const width = window.innerWidth;
const height = window.innerHeight - 10;

//adding height and width to svg
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// about scatterplot structure
const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
  	.speciesValue((d) => d.species)
    .symbolValue((d) => d.species)
    .margin({
      top: 50,
      right: 53,
      bottom: 50,
      left: 70,
    })
    .size(50);

  svg.call(plot);

  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  // display Title 
svg.append("text").attr("x", 450).attr("y", 20).text("Iris Scatterplot").style("font-size", "30px").attr("alignment-baseline","middle")

  //label for y-axis
  svg.append("text")   
        .attr("transform", "rotate(-90)")
        .attr("x", 0 - (height/2) )
        .attr("dy", "1em")
        .style("text-anchor", "middle")
        .text("sepal_length")
        .attr("font-family","Serif")
        .attr("font-size","21")
          
      //label for x-axis
   svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
      		.text("petal_width");
  //main function
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000); //for every 2000 milliseconds visualization will change
};
main();

