import {
  scaleLinear,
  scaleOrdinal,
  extent,
  axisLeft,
  axisBottom,
  symbols,
  symbol,
} from 'd3';

export const scatterPlot = () => {
  let xValue;
  let yValue;
  let width;
  let height;
  let data;
  let symbolValue;
  let speciesValue;
  let margin;
  let size;

  const my = (selection) => {
    const x = scaleLinear()
      .domain(extent(data, xValue))
      .range([margin.left, width - margin.right]);

    const y = scaleLinear()
      .domain(extent(data, yValue))
      .range([height - margin.bottom, margin.top]);

    const symbolScale = scaleOrdinal()
      .domain(data.map(symbolValue))
      .range(symbols);
    //defining different colours according to species
    const marker = (d) => {
        	switch(d){
            case 'setosa':
              return 'red';
            case 'versicolor':
              return 'blue';
            default:
              return 'orange';
          }
    }
    
//giving shape to scattered data
    const symbolGenerator = symbol().size(size);
    
    const marks = data.map((d) => ({
      x: x(xValue(d)),
      y: y(yValue(d)),
      species: speciesValue(d),
      color: marker(speciesValue(d)),
      pathD: symbolGenerator.type(symbolScale(symbolValue(d)))(),
    }));

    selection
      .selectAll('path')
      .data(marks)
      .join('path')
      .attr('d', (d) => d.pathD)
    	.attr('fill', (d) => d.color)
      .attr('transform', (d) => `translate(${d.x},${d.y})`);

    selection
      .selectAll('.y-axis')
      .data([null])
      .join('g')
      .attr('class', 'y-axis')
      .attr('transform', `translate(${margin.left},0)`)
      .call(axisLeft(y));

    selection
      .selectAll('.x-axis')
      .data([null])
      .join('g')
      .attr('class', 'y-axis')
      .attr(
        'transform',
        `translate(0,${height - margin.bottom})`
      )
      .call(axisBottom(x));
  };

  my.width = function (_) {
    return arguments.length ? ((width = +_), my) : width;
  };

  my.height = function (_) {
    return arguments.length ? ((height = +_), my) : height;
  };

  my.data = function (_) {
    return arguments.length ? ((data = _), my) : data;
  };

  my.xValue = function (_) {
    return arguments.length ? ((xValue = _), my) : xValue;
  };

  my.yValue = function (_) {
    return arguments.length ? ((yValue = _), my) : yValue;
  };
	
  my.symbolValue = function (_) {
    return arguments.length
      ? ((symbolValue = _), my)
      : symbolValue;
  };
  
  my.speciesValue = function (_) {
    return arguments.length ? ((speciesValue = _), my) : speciesValue;
  };

  my.margin = function (_) {
    return arguments.length ? ((margin = _), my) : margin;
  };

  my.size = function (_) {
    return arguments.length ? ((size = +_), my) : size;
  };

  return my;
};
